## Phoenix Stenotype

The default stenotype system of Plover translates words like `KAT/-D` as **catted** when it shouldn't translate at all.

In contrast, the `plover_minimal_english_stenotype` plugin doesn't translate words like **occurred** properly. It mistranslates as **occured** instead.

This plugin aims to fix those problems.